@@ -1,6 +1,3 @@
-from aiohttp import ClientSession
-import pytest
-
 from pyfy.async_client import AsyncSpotify
 
 
